#!/bin/bash
#
# ssh-api:rsync-api.sh
#
if [ "$( type -t echofatal )" != 'function' ] ; then
  echo "ERROR in '${BASH_SOURCE[0]}' - project https://git.cclaude.rocks/bash-apis/bash-common-api.git is required." >&2
  echo "ERROR in '${BASH_SOURCE[0]}' - source message-api.sh" >&2
  exit 1
fi

if [ "$( type -t ssh_api_test_remote_directory )" != 'function' ] ; then
  # shellcheck disable=SC1091
  source "$( dirname "${BASH_SOURCE[0]}" )/ssh-common-api.sh" || exit $?
fi

function ssh_api_rsync_directory_to_host {
  local -r _local_directory_="$1"
  local -r _ssh_user_="$2"
  local -r _ssh_host_="$3"
  local -r _ssh_remote_dir_="$4"

  if [ ! -d "${_local_directory_}" ] ; then
    echofatal "${FUNCNAME[0]}() - Directory '${_local_directory_}' not found."
    return 100
  fi

  local _ssh_ip_host_=
  _ssh_ip_host_="$( _ssh_api_common_get_ssh_host_ip_ "${_ssh_host_}" )" || return $?
  local -r _ssh_ip_host_

  if [ "$( getRSYNC_CHECK_DESTINATION )" != 'false' ] ; then
    local result=
    result="$( ssh_api_test_remote_directory "${_ssh_user_}" "${_ssh_ip_host_}" "${_ssh_remote_dir_}" )"
    local -ri result_rc=$?

    if [ "${result}" != 'FOUND' ] ; then
      echofatal "${FUNCNAME[0]}() - Directory '${_ssh_remote_dir_}' not found on host '${_ssh_ip_host_}'"
      echofatal "rc: ${result_rc} - '${result}'"
      return 100
    fi
  fi

  local _rsync_opts_=
  _rsync_opts_="$( getRSYNC_OPTS )" || return $?
  local -r _rsync_opts_

  if isRSYNC_VERBOSE ; then
cat <<EOF >&2
  command rsync ${_rsync_opts_} \
        "${_local_directory_}/" \
        "${_ssh_user_}@${_ssh_ip_host_}:${_ssh_remote_dir_}"
EOF
  fi

  # shellcheck disable=SC2086
  command rsync ${_rsync_opts_} \
        "${_local_directory_}/" \
        "${_ssh_user_}@${_ssh_ip_host_}:${_ssh_remote_dir_}"
  return $?
}

function ssh_api_rsync_directory_locally {
  local -r _local_directory_="$1"
  local -r _ssh_remote_dir_="$2"

  if [ ! -d "${_local_directory_}" ] ; then
    echofatal "Directory '${_local_directory_}' not found."
    return 100
  fi

  if [ "$( getRSYNC_CHECK_DESTINATION )" != 'false' ] ; then
    if [ ! -d "${_ssh_remote_dir_}" ] ; then
      echofatal "Directory '${_ssh_remote_dir_}' not found."
      return 100
    fi
  fi

  local _rsync_opts_=
  _rsync_opts_="$( getRSYNC_OPTS )" || return $?
  local -r _rsync_opts_

  if isRSYNC_VERBOSE ; then
cat <<EOF >&2
  command rsync ${_rsync_opts_} "${_local_directory_}/" "${_ssh_remote_dir_}"
EOF
  fi

  # shellcheck disable=SC2086
  command rsync ${_rsync_opts_} "${_local_directory_}/" "${_ssh_remote_dir_}"
  return $?
}
